//==============================================================================
// aq_class_attitudefile.c
//
// 
// 21 May 2001 Version 1.0
//
// Purpose:
// 	This class defines an attitude output file in SDP format.
//
// Note:
//	Headers are written when file is closed, so headers can be updated any
//	time before closure.  Headers passed to file constructor must not be 
//	destroyed before file closure. 
//
//	See SDP Toolkit 333-CD-600-001 Appendix L, Ephemeris and Attitude File
//	Formats.
//
//	General structure is:
//		SDP header
//		attitude subheader
//		attitude records

//
//==============================================================================

#include  "aq_class_attitudefile.h"


//-------------------------------------------------------------------------------
// Constructor
//
//	write initial headers (updated later in destructor)
//-------------------------------------------------------------------------------


attitudefile::attitudefile
( 
    const string& fileName, 
    const commonSDPheader&   comHeader,
    const attitudesubheader& attHeader
)   
   : ofstream( fileName.c_str() ), 
     basefile( fileName, "attitude" ),
     _comHeader(comHeader),
     _attHeader(attHeader)
{
    _comHeader.lock();    
    _attHeader.lock();    

    ofstream::write( _comHeader.DataPtr(), _comHeader.DataSize() );
    ofstream::write( _attHeader.DataPtr(), _attHeader.DataSize() );
}


//page
//-------------------------------------------------------------------------------
// Write Attitude Records
//
// update headers
//-------------------------------------------------------------------------------

attitudefile& attitudefile::write(const attituderecord& attRcd )
{
    ofstream::write( attRcd.DataPtr(), attRcd.DataSize() );
    return *this;
}


//-------------------------------------------------------------------------------
// close()
//
// update headers
//-------------------------------------------------------------------------------

void attitudefile::close()
{
    seekp(0);
    ofstream::write( _comHeader.DataPtr(), _comHeader.DataSize() );
    ofstream::write( _attHeader.DataPtr(), _attHeader.DataSize() );
}


//-------------------------------------------------------------------------------
// Destructor
//
//-------------------------------------------------------------------------------

attitudefile::~attitudefile()
{
    close();

    _comHeader.unlock();    
    _attHeader.unlock();    
}


