//==============================================================================
// aq_class_attitudefile.h
//
// 
// 21 May 2001 Version 1.0
//
// Purpose:
// 	This class defines an attitude output file in SDP format.
//
// Note:
//	Headers are written when file is closed, so headers can be updated any
//	time before closure.  Headers passed to file constructor must not be 
//	destroyed before file closure. 
//
//	See SDP Toolkit 333-CD-600-001 Appendix L, Ephemeris and Attitude File
//	Formats.
//
//	General structure is:
//		SDP header
//		attitude subheader
//		attitude records
//
//==============================================================================

#if !defined( AQ_CLASS_ATTITUDEFILE)
#define       AQ_CLASS_ATTITUDEFILE

#include <fstream>
#include "aq_class_commonSDPheader.h"
#include "aq_class_attitudesubheader.h"
#include "aq_class_basefile.h"
#include "aq_typdef_header.h"
#include "aq_class_attituderecord.h"


//-----------------------------------------------------------------------------
// attitudefile
//
//-----------------------------------------------------------------------------

class attitudefile :  public ofstream, public basefile
{
    const  commonSDPheader&   _comHeader;
    const  attitudesubheader& _attHeader;

public:

    attitudefile( 
	cstring& fileName, 
	const    commonSDPheader& comHeader,
        const    attitudesubheader& attHeader 
    );

    attitudefile& write(const attituderecord& attRcd );
    void close();

   ~attitudefile();
};

#endif



