//==============================================================================
// aq_class_attituderecord.h
//
// 
// 17 May 2001 Version 1.0
//
// Purpose:
// 	This class holds attitude data records to be written.
//
// Note:
//	See SDP Toolkit 333-CD-600-001 Appendix L, Ephemeris and Attitude File
//	Formats.
//
//      Input Time is TAI Julian Date.  
//	See Theoretical Basis of the SDP Toolkit Geolocation Package for the
//	ECS Project, 445-TP-002-002, May 1995, Section 4.6.3,
//	Section 4.8.1, page 4-19
//
//==============================================================================


#if !defined(AQ_CLASS_ATTITUDERECORD)
#define      AQ_CLASS_ATTITUDERECORD

#include <string.h>
#include <assert.h>

#include "aq_class_storebase.h"
#include "aq_typdef_header.h"


class attituderecord : public storebase
{
public:
    attituderecord();
    attituderecord&  Time( double JDtime );
    attituderecord&  EulerAngles( carray& angles );
    attituderecord&  AngleVelocities( carray& avel );
    attituderecord&  QaFlag( uint flags );

    double Time() const;
    carray EulerAngles() const;
    carray AngleVelocities() const;
    uint   QaFlag()   const;

    const char* Spares() const;		// diagnostics only
    char*  Spares();
};

#endif





