//==============================================================================
// aq_class_attitudesubheader.c
//
// 
// 18 May 2001 Version 1.0
//
// Purpose:
//     This class defines portion of SDP Header Standard Sructure specific to 
//     the ephemeris header.
//
// Note:
//	See SDP Toolkit 333-CD-600-001 Appendix L, Ephemeris and Attitude File
//	Formats.
//
//==============================================================================

#include "aq_class_attitudesubheader.h"
#include "aq_proc_formatconvert_x.h"		// machine-dependent formats
#include <string.h>

attitudesubheader::attitudesubheader() : storebase(372) 
{ }
    

attitudesubheader& attitudesubheader::AngleOrder( uint r1, uint r2, uint r3 )
{
    FormatConvert_long4( r1, DataPtr()   );
    FormatConvert_long4( r2, DataPtr()+4 );
    FormatConvert_long4( r3, DataPtr()+8 );

    return *this;
}


vector<uint> attitudesubheader::AngleOrder() const
{
    vector<uint> order(3);

    order[0] = FormatConvert_long4( DataPtr()   );
    order[1] = FormatConvert_long4( DataPtr()+4 );
    order[2] = FormatConvert_long4( DataPtr()+8 );

    return order;
}


//page
//------------------------------------------------------------------------------
// qaParameters
//              beg = 12  end = 75  cnt = 64   	
//
//------------------------------------------------------------------------------

 vector<float> attitudesubheader::qaParameters() const
{
    vector<float> qap(16);
    char  *ptr = DataPtr() + 12;

    for(size_t i = 0; i<16; i++)  
	qap[i] = FormatConvert_float4( ptr+i*4 );	

    return qap;
}


//------------------------------------------------------------------------------
// qaStatistics
//              beg = 76  end = 91  cnt = 16   	
//
//------------------------------------------------------------------------------

 vector<float> attitudesubheader::qaStatistics() const
{
    vector<float> stat(4);
    char  *ptr = DataPtr() + 76;

    for(size_t i = 0; i<4; i++)  
	stat[i] = FormatConvert_float4( ptr+i*4 );	

    return stat;
}




