//==============================================================================
// aq_class_ephemerisfile.h
//
// 
// 21 May 2001 Version 1.0
//
// Purpose:
// 	This class defines an ephemeris output file in SDP format.
//
// Note:
//	Headers are written when file is closed, so headers can be updated any
//	time before closure.  Headers passed to file constructor must not be
//	destroyed before file closure.
//
//	See SDP Toolkit 333-CD-600-001 Appendix L, Ephemeris and Attitude File
//	Formats.
//
// 	General format:
//	SDP Header
//	ephemeris subheader
//	ephemeris records
//	metadata  records
//
//==============================================================================

#if !defined( AQ_CLASS_EPHEMERISFILE)
#define       AQ_CLASS_EPHEMERISFILE

#include <fstream>
#include "aq_class_commonSDPheader.h"
#include "aq_class_ephemerismetadata.h"
#include "aq_class_ephemerissubheader.h"
#include "aq_class_ephemerisrecord.h"
#include "aq_class_basefile.h"
#include "aq_typdef_header.h"


//------------------------------------------------------------------------------
// ephemerisfile
//
//------------------------------------------------------------------------------

class ephemerisfile : public ofstream, public basefile
{
    const commonSDPheader&    _comHeader;
    const ephemerissubheader& _ephHeader;

public:

    ephemerisfile( 
    	const string& fileName, 
    	const commonSDPheader&     comHeader,
    	const ephemerissubheader&  ephHeader
    );

    ephemerisfile& write(const ephemerisrecord&   ephRcd  );
    ephemerisfile& write(const ephemerismetadata& metaRcd );
    void close();

    ~ephemerisfile();
};

#endif




