//==============================================================================
// aq_class_ephemerismetadata.h
//
// 
// 17 May 2001 Version 1.0
//
// Purpose:
//      This class holds ephemeris metadata records to be written.
//
// Note:
//	Headers are written when file is closed, so headers can be updated any
//	time before closure.  Headers passed to file constructor must not be
//	destroyed before file closure.
//
// 	General format:
//	SDP Header
//	ephemeris subheader
//	ephemeris records
//	metadata  records
//
//	See SDP Toolkit 333-CD-600-001 Appendix L, Ephemeris and Attitude File
//	Formats.
//
//==============================================================================


#if !defined(AQ_CLASS_EPHEMERISMETADATA)
#define      AQ_CLASS_EPHEMERISMETADATA

#include <string.h>
#include <assert.h>

#include "aq_class_storebase.h"
#include "aq_typdef_header.h"


class ephemerismetadata : public storebase
{
public:
    ephemerismetadata();
    ephemerismetadata&  OrbitNo( uint orbitNo );
    ephemerismetadata&  AscendingTime(  double time );
    ephemerismetadata&  DescendingTime( double time );
    ephemerismetadata&  DescendingLongitude( double longitude);

    uint   OrbitNo() const;
    double AscendingTime()  const;
    double DescendingTime() const;
    double DescendingLongitude() const;

    double AscendingTimeTAI() const; 	// diagnostic
};

ostream& operator<<(ostream& os,  const ephemerismetadata& ephemdata );

#endif




