//=============================================================================
// aq_class_gbadinterpolator.c
//
// 
// 10 Jan 2002 Version 1.0
//
// Description:
//
// 	This class onstructs an interpolator for each of:
//	p[ 0] - p[ 2] 	position
//	p[ 3] - p[ 5] 	velocity
//	p[ 6] - p[ 9] 	attitude
//	p[10] - p[12]   attitude rate.
//
// The  interpolators are initialized from packets in a windowbuffer.
// interpolate() returns 13 element array of values interpolated to time.
//
//
//=============================================================================


#include "aq_class_gbadinterpolator.h"


//-----------------------------------------------------------------------------
// load
//	For each packet in window buffer, get values and place in interpolators
//
//-----------------------------------------------------------------------------

void gbadinterpolator::load( const windowbuffer<extgbadpacket>& wbuf )
{
    for(size_t i=0; i<13; i++) interpolators[i].clearlist();

    for( size_t bufferIndex=0; bufferIndex<wbuf.length(); bufferIndex++)
    {
        const  gbadpacket *pktPtr = wbuf.peek( bufferIndex );
        array  list = pktPtr->ItemList();
        double time = pktPtr->TimeTag ();

        for( size_t valueIndex=0; valueIndex<13; valueIndex++)
	{
            interpolators[ valueIndex ].addtolist( time, list[valueIndex] );
	}
    }
}


//page
//-----------------------------------------------------------------------------
// interpolate
//
//	assemble interpolated values into an arrary and return
//-----------------------------------------------------------------------------

array gbadinterpolator::interpolate( double time )
{
    array values(13);

    for( size_t valueIndex=0; valueIndex<13; valueIndex++)
    {
        values[valueIndex] = interpolators[ valueIndex ].interpolate( time );
    }

    return values;
}


