//==============================================================================
// aq_class_nevilleinterpolater.c
//
// 
// 13 Jun 2001 Version 1.0
// 28 May 2002         1.1 - add <assert.h>
//
// Neville's recursive interpolater.
//
// from pairs 
//	  (X1,Y1)....(X4,Y4),
//
// construct:
//
//        x(1):   y(1) = P[1:1]
//                                P[1:2]
//        x(2):   y(2) = P[2:2]           P[1:3]
//                                P[2:3]          P[1:4]
//        x(3):   y(3) = P[3:3]           P[2:4]
//                                P[3:4]
//        x(4):   y(4) = P[4:4]
//
// from:
//                 (x(j) - x)*P[i:j-1] + (x - x(i))*P[i+1:j]
//      P[i:j] = -----------------------------------------
//                            x(j) - x(i)
// 
// starting with P(1,4)
//
//
// In the code below, "xylist" is a list of xy pairs. The xylist optionally be
// specified in the constructor or with the "setxylist member function. The list 
// need not be evenly spaced along x. 

//
//==============================================================================

#include  "aq_class_nevilleinterpolater.h"
#include  <assert.h>

//page
//------------------------------------------------------------------------------
// P-
//	private procedure to implment recursive interpolater
// 
//------------------------------------------------------------------------------

    double nevilleinterpolater::P(size_t i, size_t j ) const
    {   
	if( i==j ) return (*xy)[i-1].second;

	double Xi = (*xy)[i-1].first;
	double Xj = (*xy)[j-1].first;
	
        return ( ( Xj - x ) * P(i,j-1) + (x - Xi) * P(i+1,j) ) / (Xj - Xi);
    }


//------------------------------------------------------------------------------
// constructor
// 
//------------------------------------------------------------------------------

    nevilleinterpolater::nevilleinterpolater( const dblplist* xylistPtr) 
  	: xy( xylistPtr )
    { }


//------------------------------------------------------------------------------
// setxylist
// 
//	set new xylist
//------------------------------------------------------------------------------

     nevilleinterpolater& nevilleinterpolater::setxylist( const dblplist* xylist)
     {
	xy = xylist;
	return *this;
     }


//------------------------------------------------------------------------------
// interpolate
// 
// 	return interpolated y value for given x value
//------------------------------------------------------------------------------

    double nevilleinterpolater::interpolate( double xvalue ) const
    {
	assert( xy != 0 );
	x = xvalue;
	return P( 1, (*xy).size() );
    }




