//==============================================================================
// aq_class_noradfile.c
//
// 
// 22 May 2001 Version 1.0
//
// Purpose:
// 	This class defines a NORAD Two-Line Element Set input file
//
// Note:
// 	file contains satellite names followed by current NORAD two-line elements. 
//	Empty lines are permited:
//
//AQUA
//1 20643U 90051A   00106.74030013 -.00000098  00000-0  10000-3 0  3799
//2 20643   1.7872  88.9300 0010028 254.0669 201.5776  1.00266665 22906
//
//==============================================================================

#include "aq_class_noradfile.h"
#include <ctype.h>




//------------------------------------------------------------------------------
// Constructor
//
//------------------------------------------------------------------------------

noradfile::noradfile( cstring& fileName, cstring& _satName ) 
: ifstream( fileName.c_str() ), basefile( fileName, "norad" )
{
    satName =_satName;
    if( satName.size()==0 || isspace(satName[0]) ) satName = "$$$$";
}


//------------------------------------------------------------------------------
// readline- local helper procedure 
//
//	 read and skip lines with only white space 
//------------------------------------------------------------------------------

static void readline( noradfile& nfile, string& line )
{
    while( nfile )
    {
	getline( nfile, line);
        //cout<<"##"<<line<<"##";
	for(size_t k=0; k<line.size(); k++) if( !isspace(line[k]) ) return;
    }
}


//page
//------------------------------------------------------------------------------
// read norad elements
//
//------------------------------------------------------------------------------

noradfile& noradfile::read( noradelements& noradtle )
{
    line1.erase();
    line2.erase();
    
    while( *this )
    {
        readline( *this, line1 );
        //cout<<"**"<<line1<<"**";
        //if(line1[line1.length()-1]=='\r') cout<<"End is \r";
            
        
        if( line1.find(satName) == (size_t)(-1) ) continue;
         
        
        
        //cout<<"line1.length="<<line1.length()<<" satName.length="<<satName.length()<<"after last character="<<line1.substr( satName.length(), 1);
        //cout<<"Compare:"<<line1.substr( satName.length(),1).compare(" ")<<'\n';
        
        
        //Line name length must = Satname length OR next linename char must = " " OR next linename char = '\r' (Carriage return, ASCII 13)
        if( line1.length() == satName.length() || line1.substr( satName.length(),1).compare(" ")==0  || line1[satName.length()]=='\r' ){ 
                cout<<line1<<" MATCHED "<<satName<<" "<<line1.find(satName)<<'\n';
                readline( *this, line1 );
                readline( *this, line2 );
                cout<<line1<<line2<<'\n';
                noradtle.Set( line1, line2 );
                break;
        }

        
    }

    return *this;
}


//------------------------------------------------------------------------------
// print buffers
//
//------------------------------------------------------------------------------

void noradfile::print( ostream& os )  const
{
    os<<"\nline1 = "<<line1<<"\nline2 = "<<line2<<endl;
}






