//==============================================================================
// aq_class_packet.c
//
// 
// 17 May 2001 Version 1.0
//
// This is intended as a base class for CCSDS packets
//
// Note:
//	Packet size in constructor is total size of packet = CCSDS header +
//	time + data.
//
//	Packet size returned by PktSize is size of data-zone = time_stamp +
//	data  as reported by packet. (1 is added to value in header field) 
//
//==============================================================================

#include <iostream>
#include <iomanip>
#include <string.h>
#include <assert.h>
#include "aq_class_packet.h"
#include "aq_proc_formatconvert_x.h"


//------------------------------------------------------------------------------
// constructor-
//	size is size of packet = CCSDS Header + time + data
//------------------------------------------------------------------------------

packet::packet(size_t _size) : storebase( _size )
{ }


//page
//------------------------------------------------------------------------------
// PktSize-
//	Data size from CCSDS packet header
//------------------------------------------------------------------------------

short packet::PktSize() const
{
    return FormatConvert_short2(DataPtr()+4) + 1;
}


//------------------------------------------------------------------------------
// Sequence-
//	packet sequence number from CCSDS packet header
//------------------------------------------------------------------------------

short packet::Sequence() const
{
    return  FormatConvert_short2( DataPtr()[2] & 0x3f, DataPtr()[3] );
}


//------------------------------------------------------------------------------
// APID-
//	Application ID from CCSDS packet header
//------------------------------------------------------------------------------

short packet::APID() const
{
    return  FormatConvert_short2( DataPtr()[0] & 0x7, DataPtr()[1] );
}


//------------------------------------------------------------------------------
// Version-
//	CCSDS packet header version number
//------------------------------------------------------------------------------
    
short packet::Version() const
{
    return DataPtr()[0] / 32;
}


//------------------------------------------------------------------------------
// ReadPkt-
//
//------------------------------------------------------------------------------

istream& packet::ReadPkt(istream& is)
{
    is.read( DataPtr(), DataSize() );
    return is;
}


//page
//------------------------------------------------------------------------------
// Dump
//	hex dump of packet for diagnostics
//------------------------------------------------------------------------------

void packet::Dump( ostream& os, size_t beg, size_t end )
{
    if( !end ) end = PktSize();
    size_t k = 0;

    for(size_t i=beg; i<end; i++)
    {
	if( k && (k==k/20*20) ) os<<'\n'<<endl;
	k++;

        os<<hex<<setfill('0')<<setw(2)<<FormatConvert_short2(0,DataPtr()[i])<<' ';
    }
}



//------------------------------------------------------------------------------
// operator<<
//	diagnostic ascii dump
//------------------------------------------------------------------------------

ostream&  operator<<( ostream& os, const packet& pkt)
{
    os<<dec
      <<"\npacket_ver. = "<<pkt.Version()
      <<"\npacket_APID = "<<pkt.APID()
      <<"\npacket_seq. = "<<pkt.Sequence()
      <<"\npacket_size = "<<pkt.PktSize()
      <<flush;

    return os;
}






