//=============================================================================
// aq_class_repairpktstream.c
//
// 
// 11 Jan 2002 Version 1.0
// 08 Aug 2003 Version 1.1 - modify "while" to check no of packets in file and
//			     set "eof" to  tell rest of program file was read.
//			     Add logic to check for time order. 
//
// Replace missing GBAD packets by interpolating between gaps and set qualilty
// flags related to gaps. 
//
// See SDP ToolKit Appendix L, Ephemeris and Attitude Formats for flag
// descriptions.
//
// getfixedpkt() returns pointer to successive packects in a stream repaired by
// interpolating across gaps.
//
//
//=============================================================================

#include "aq_class_repairpktstream.h"
#include <cstdlib>
//-----------------------------------------------------------------------------
// clearPkt -private procedure
//
//	save quality flags then clear flags from current buffer
//-----------------------------------------------------------------------------

gbadpacket*  repairpktstream::clearPkt( extgbadpacket& pkt )
{
    qFlags = pkt;
    pkt.clear( );

    return &pkt;
}


//-----------------------------------------------------------------------------
// constructor
//
//-----------------------------------------------------------------------------

repairpktstream::repairpktstream( packetfile& pfile ) 
: pktfile(pfile), wbuffer(7)
{
    smallGapFlag = false;
    lastPktRead  = 0;
    thisTime = 0;
    nextTime = 0;
    thisPkt  = 0;
    pktno    = 0;
}


//page
//-----------------------------------------------------------------------------
// getfixedpkt
//
//-----------------------------------------------------------------------------

gbadpacket* repairpktstream::getfixedpkt( )
{
    if( !smallGapFlag)
    {   
 	while( pktfile )	// fill window buffer
        {
	    if( pktno >= pktfile.NoPackets() )
	    {
		pktfile.setstate(ios::eofbit);
		break;
	    }

	    if( !wbuffer.addflag() ) break;
	    pktfile.ReadPacket( *(lastPktRead = wbuffer.add()),  pktno++ );
        }
				// get two consecutive pkts
        thisPkt = wbuffer.get( );
        extgbadpacket* nextPkt = wbuffer.next( );

				// done
        if( !thisPkt ) return 0;
	if( !nextPkt ) return thisPkt;

	thisTime = thisPkt->TimeTag();
	nextTime = nextPkt->TimeTag();

	if( nextTime <= thisTime )
	{
	    cerr<<"\npacket Time order error:\n\n"
		<<(*thisPkt)<<"\n\n"<<(*nextPkt)<<"\n"<<endl;

	    exit(-1);
	}

				// Gap greater than 1 minute
	if( nextTime-thisTime > 60.0/86400.0L )
	{
	    thisPkt->setLargeGapFollows();
	    nextPkt->setLargeGapBefore ();
	    
	    return clearPkt( *thisPkt );
	}
				// Gap less than 1 minute
	if( smallGapFlag = nextTime-thisTime > 1.1/86400.0L )
        {	
	    thisPkt->setSmallGapFollows();
	    nextPkt->setSmallGapBefore();

	    gbadInterpolator.load( wbuffer );
	}

	return clearPkt( *thisPkt );
    }
    else			// Generate interpolated packets
    {
	if( (thisTime += 1.0/86400.0L) >= (nextTime -1.1/86400.0L) )
	    smallGapFlag = false;
	
	thisPkt->ItemList() = gbadInterpolator.interpolate( thisTime );
	thisPkt->setGapRepaired();
	thisPkt->TimeTag( thisTime );

	return clearPkt( *thisPkt  );
    }
}


//page
//-----------------------------------------------------------------------------
// getLastPktRead
//
//-----------------------------------------------------------------------------

const gbadpacket*   repairpktstream::getLastPktRead() 
{ 
    return lastPktRead; 
}





