//=============================================================================
// aq_proc_CopyEphemerisMetaData.c - write metadata footers to Ephemeris File
//
// 
// 16 Jan 2002 Version 1.0
//
//	Get list of orbits (orbitstuff structs) assembled by "pktprocessor",
//	then loop thru list, using "satPass" to compute orbit parameters
//	which are loaded into "ephemerismetadata" structs and written to file.
//	
//=============================================================================


#include  "aq_class_satpasses.h"
#include  "aq_class_orbitstuff.h"
#include  "aq_class_ephemerismetadata.h"
#include  "aq_proc_CopyEphemerisMetaData.h"


void CopyEphemerisMetaData( 
     gbadpktprocessor&    pktprocessor, 
     const noradelements& noradtle, 
     ephemerisfile&       efile ,
     const cfg_list&      configList 	// from configuration file
)
{
    ephemerismetadata metaRcd;		// metadata record 
    satpasses satPass( noradtle );	// compute orbit parameters

					// diagnostic
    bool printPass = false;
    if( configList.getvalue("-diag_2")==(string)"yes" ) printPass = true;

    const vector<orbitstuff>& orbits = pktprocessor.GetOrbitList();

    for( size_t k = 0; k<orbits.size(); k++)
    {
		cout<<"\nbeg loop"<<endl;
    	satPass.SetOrbit( orbits[k] );
		cout<<"\norbit stuff = "<<orbits[k]<<endl;

		if( printPass) cerr<<"\ndiag_2 SatPass["<<k<<"]\n"<<satPass<<endl;
		cout<<"\nCopyEphemerisMetadata debug 0"<<endl;
	
    	metaRcd.OrbitNo( satPass.BegOrbitRev() );
		cout<<"\nCopyEphemerisMetadata debug 1"<<endl;
		
    	metaRcd.AscendingTime( satPass.AscendingNodeTime() );
		cout<<"\nCopyEphemerisMetadata debug 2"<<endl;
    	
		metaRcd.DescendingTime(satPass.DescendingNodeTime() );
		cout<<"\nCopyEphemerisMetadata debug 3"<<endl;
    	
		metaRcd.DescendingLongitude( satPass.DescendingNodeLongitude() );
		cout<<"\nCopyEphemerisMetadata debug 4"<<endl;

    	efile.write(metaRcd);
		cout<<"\nCopyEphemerisMetadata debug 5"<<endl;
    }
}
