//=============================================================================
// aq_proc_CopyFiles.c
//
// Coded by C. Hoisingon, Science Systems and Applications, Inc.
// 16 Jan 2002
// 11 Aug 2003 - dereference pointer in error message
//
// 	Read packets from packet file and write Ephemeris and Attitude files.
//
//      "processPkt" accummulates file-wide statistics and does processing that
//	spans packets. It repairs record gaps.
//=============================================================================

#include  "aq_class_ephemerisrecord.h"
#include  "aq_class_attituderecord.h"
#include  "aq_proc_euleranglesinorbitalframe.h"
#include  "aq_proc_CopyFiles.h"
#include  "aq_class_qualityflags.h"


void  CopyFiles( 

      gbadpktprocessor&  processPkt, 	// input packet processor
      ephemerisfile&     efile, 	// output ephemeris file
      attitudefile&      afile, 	// output attitude file
      const cfg_list&    configList 	// configuration file
)
{
    ephemerisrecord eRcd;
    attituderecord  aRcd;
    gbadpacket     *pktPtr;

    while (pktPtr = processPkt.ReadPkt() )
    {
	eRcd.time( pktPtr->TimeTag() );
	eRcd.Position( pktPtr->Position() );
	eRcd.Velocity( pktPtr->Velocity() );
	eRcd.QaFlag( processPkt.QualityFlags().getqualityflags().to_ulong() );

	aRcd.Time( pktPtr->TimeTag() );
	aRcd.EulerAngles( EulerAnglesInOrbitalFrame( *pktPtr ) );
	aRcd.AngleVelocities( pktPtr->AngleRates() );
	aRcd.QaFlag( processPkt.QualityFlags().getqualityflags().to_ulong() );

	efile.write( eRcd );
	afile.write( aRcd );
    }
						// Error if not EOF
    if( !processPkt.PacketFile().eof() ) 
    {
	cerr<<"\nPacket File read error"<<endl;
	cerr<<'\n'<<*(processPkt.getLastPktRead())<<endl;
	exit(-1);
    }
}


