//==============================================================================
// aq_proc_quaterniontoeuler.c
//
// 
// 01 Jun 2001 Version 1.0
//
// This procedure computes the Euler 312 angle rotation sequence 
// (roll, pitch yaw) from a quaternion.
// 
// See "Spacecraft Attitude and Control", James R.Wertz, 1994, section 12.
//
//==============================================================================


#include "aq_proc_quaterniontoeuler.h"
#include <math.h>


carray QuaternionToEuler( carray& q )
{
    array angle(3);

    angle[0] = +asin( 2*(q[1]*q[2] + q[0]*q[3]) ); 

    angle[1] = -atan2( 2*(q[0]*q[1] - q[2]*q[3]),
		       -q[0]*q[0] + q[1]*q[1] - q[2]*q[2] + q[3]*q[3] );

    angle[2] = -atan2( 2. * (q[0]*q[2] - q[1]*q[3]),
		       -q[0]*q[0] - q[1]*q[1] + q[2]*q[2] + q[3]*q[3] ); 

    return angle;
}



