//==============================================================================
// orbitlib_class_NoradElements.h
//
// 29 Feb 2000 	Version 1.0
//
//      See the United States Air Force Aerospace Defense Command Document, 
//      "Project Space Track, Models for propagation of NORAD Element Sets", 
//	December 1980.
// 
//
// This class provides NORAD Element Set Conversions. Unit conversions are those
// found in the original Driver for the NORAD Models.
//
//	angles are positive principle angles. 
//    
//	V[0] = XNO    -  mean motion     line 2, col 53-63      radians/minute
//	V[1] = EO     -  eccentricity    line 2, col 27-33	none
// 	V[2] = XINCL  -  inclination     line 2, col 09-16      rad.
//  	V[3] = XNODEO -  right ascen.    line 2, col 18-25	rad.
//	V[4] = OMEGAO -  arg. of perigee line 2, col 35-42	rad.
//      V[5] = XMO    -  mean anomaly	 line 2, col 44-51	rad.
//	V[6] = BSTAR  -  drag term	 line 1, col 54-61	earthradii**-1
//
//	not required by  SGP4 model:
//
//	V[7] = XNDT2O -  		 line 1, col 34-43      rev/min**2
//	V[8] = XNDD6O -			 line 1, col 45-52      rev/min**3 
//
//      V[9] = 		 satellite no.   line 1, col 03-07
//      V[10]= 		 year            line 1, col 19-20
//      V[11]=           day             line 1, col 21-32
//	V[12]=           epoch rev       line 2, col 64-68
//
//==============================================================================

#if !defined(ORBITLIB_NORADELEMENTS)
#define      ORBITLIB_NORADELEMENTS

#include <vector>
#include <string>
#include <iostream>
 using namespace std;


//page
//------------------------------------------------------------------------------
// class noradelements
//
//------------------------------------------------------------------------------

class noradelements
{
    bool checksumValid;
    vector<double> V;

public:
    noradelements ();
    noradelements ( const string& line1, const string& line2 );
    noradelements ( const vector<double>& V );
    noradelements ( const noradelements&  N );

    noradelements&  Set( const string& line1, const string& line2 );
    noradelements&  Set( const vector<double>& V );
    noradelements&  Set( const noradelements&  N );

    const vector<double> Get()  const;
    void Get( string& line1, string& line2) const;
    void Print( ostream& os)  const;

    bool operator!() const;
};

#endif
