//------------------------------------------------------------------------------
// orbitlib_proc_ConvertJ2000ToMean.c
//
//      29 Oct 2002 Version 1.0
//
// Convert inertial coordinates to mean of date.  See "Goddard Trajectory 
// Determination System", Mathematical Theory Revision 1, July 1989, 
// section 3.3.1.1, J2000.0 Inertial to Mean of Date.
//
// Note:
//	Reference epoch defaults to 2451545.0 = January 1.5, 2000.
//	Resultant matrix rotates coordinates from ref_epoch to to data_epoch.
//
// NOT CURRENTLY USED
//------------------------------------------------------------------------------

#include <math.h>
#include <iomanip>
#include <iostream>

#include "constlib_MathConstants.h"
#include "orbitlib_proc_ConvertJ2000ToMean.h"

//page
matrix convertJ2000ToMean( double data_epochJD, double ref_epochJD )
{
    double t = (ref_epochJD - data_epochJD) / 36525;
    double t2= t*t ;
    double t3= t*t2;

    double T = (ref_epochJD - 2451545.0   ) / 36525;		// eq. 3-7
    double T2= T*T;

    double zeta0 = (2306.2181 + 1.39656*T - 0.000139*T2)*t 	// eq. 3-4
		 + (0.30188   - 0.000344*T)*t2
	    	 +  0.017998*t3;

    double thetap= (2004.3109 - 0.85330*T - 0.000217*T2)*t	// eq. 3-5
		 + (-0.42665  - 0.000217*T)*t2
		 -  0.041833*t3;

    double xip   = (2306.2181 + 1.39656*T - 0.000139*T2)*t	// eq. 3-6
		 + (1.09468   + 0.000066*T)*t2
		 +  0.018203*t3;

    // Convert seconds of arc to radians
    const double mtr = (1.0 / 1296000.0) * math_const_twoPi;

    zeta0  *= mtr;
    thetap *= mtr;
    xip    *= mtr;

    double sin_zeta0  = sin(zeta0);
    double sin_thetap = sin(thetap);
    double sin_xip    = sin(xip);

    double cos_zeta0  = cos(zeta0);
    double cos_thetap = cos(thetap);
    double cos_xip    = cos(xip);

    matrix a(3,3);
								// eq. 3-10
    a(1,1) = -sin_zeta0 * sin_xip + cos_zeta0 * cos_xip * cos_thetap;
    a(1,2) = -cos_zeta0 * sin_xip - sin_zeta0 * cos_xip * cos_thetap;
    a(1,3) = -cos_xip   * sin_thetap;

    a(2,1) =  sin_zeta0 * cos_xip + cos_zeta0 * sin_xip * cos_thetap;
    a(2,2) =  cos_zeta0 * cos_xip - sin_zeta0 * sin_xip * cos_thetap;
    a(2,3) = -sin_xip   * sin_thetap;

    a(3,1) =  cos_zeta0 * sin_thetap;
    a(3,2) = -sin_zeta0 * sin_thetap;
    a(3,3) =  cos_thetap;

    return a;
}


