//------------------------------------------------------------------------------
//
// orbitlib_proc_ConvertKeplerToRectangular.c - 
//
//
//      Computes geocentric inertial rectangular elements 
//      from osculating keplerian elements. The implementation follows "Brouwer-
//      Lyaddane Orbit Generator Routine", X-553-70-223, E. A. Galbreath, 
//      June 1970.
//
//      input: 
//
//	V[0] = A	semi major axis	  (meters)
//      V[1] = e	eccentricity
//      V[2] = i	incliniation	  (radians)
//      V[3] = N	Ascending Node    (radians)
//      V[4] = w	Angle of Perigee  (radians)
//      V[5] = m 	Mean Anomaly	  (radians)
//
//      returns:
//
//	V[0] = x  	(meters)
//	V[1] = y 	(meters)
//	V[2] = z	(meters)
//	V[3] = xdot 	(meters/sec)
//	V[4] = ydot 	(meters/sec)
//	V[5] = zdot 	(meters/sec)
//
//------------------------------------------------------------------------------


#if !defined(ORBITLIB_CONVERTKEPLERTORECTANGULAR)
#define      ORBITLIB_CONVERTKEPLERTORECTANGULAR


#include <vector>
 using namespace std;

vector<double>  Convert_KeplerToRectangular (const vector<double>& V); 


#endif

