//=============================================================================
// orbitlib_proc_QuaternionToAttitudeMtx.c
//
// 25 Oct 2001 Version 1.0
//
// Purpose:
//	Compute equivalent attitude matrix from a normalized quaternion
// 	
// Method:  
//	See "Satellite Attitude Determination and Control", Wertz, section 12.1
//
// Note:
//	Q is 4-entry array; last entry is scaler part of quaternion.
//
//===========================================================================

#include "orbitlib_proc_QuaternionToAttitudeMtx.h"


matrix QuaternionToAttitudeMtx( carray& Q )
{
    const double &q1 = Q[0];
    const double &q2 = Q[1];
    const double &q3 = Q[2];
    const double &q4 = Q[3];

    matrix A(3,3);
    	A(1,1) = +q1*q1 - q2*q2 - q3*q3 + q4*q4;
	A(1,2) = 2 * (q1*q2 + q3*q4 );
	A(1,3) = 2 * (q1*q3 - q2*q4 );
	
	A(2,1) = 2 * (q1*q2 - q3*q4 );
	A(2,2) = -q1*q1 + q2*q2 - q3*q3 + q4*q4;
	A(2,3) = 2 * (q2*q3 + q1*q4 );

	A(3,1) = 2 * (q1*q3 + q2*q4);
	A(3,2) = 2 * (q2*q3 - q1*q4);
	A(3,3) = -q1*q1 - q2*q2 + q3*q3 + q4*q4;

    return A;
}



